==> haskell-tamarin-prover-export-1.10.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-7J3xqjaPGnY5O6o2Octb89
key:                  tamarin-prover-export-1.10.0-7J3xqjaPGnY5O6o2Octb89
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  5b6c695ced082f38f976ab4acf933161
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-7J3xqjaPGnY5O6o2Octb89
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-EG3cK65raAk6aH5DHb71Yl
    tamarin-prover-term-1.10.0-1FoiPfvvxd3I3guJFyXl62
    tamarin-prover-theory-1.10.0-CDkOwQkG2FMAokMRJiIeCA
    tamarin-prover-utils-1.10.0-4erf8FjhIHb5Z4BjNR82qw text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.10.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-57kmoLtqnWWJpqvre8K79S
key:                  tamarin-prover-export-1.10.0-57kmoLtqnWWJpqvre8K79S
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  8461dee42e6d68955ea8d408e1b0a566
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-57kmoLtqnWWJpqvre8K79S
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-97r1FXtZNyl1ha70pfNRxi
    tamarin-prover-term-1.10.0-76IpeHZAplw7O0TWCr6bDm
    tamarin-prover-theory-1.10.0-BsbJtllzDf05ELOK3Ok2zJ
    tamarin-prover-utils-1.10.0-GHYWKt3jYn2CGPF9Wn3S5 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
